searchData={"items":[{"type":"module","title":"SpaPlug","doc":"A plug for serving single page apps.\n\nIt works by using a second `Plug.Static` plug, and relies on rewriting the request `conn.path_info`, so this may have side effects on your pipelines.\nFor example, to log original incoming request paths you may want to put your logging plug before `SpaPlug`.\nIt inherits all the options from `Plug.Static`, so these two are also required:\n\n  * `:at` - the request url path to host the assets at, usually \"/\"\n\n  * `:from` - file path of the assets\n\nNew options:\n\n  * `:except` - a list of url prefixes to be excluded, incoming requests matching any one of the list will not fallback to the `:index` if the file is not found. The paths should be urlencoded. Defaults to `[\"/api\", \"/dev\", \"/metrics\"]`.\n\n  * `:index_merge_opts` - `Plug.Static` options except `:only` for the index specifically, to be merged with base options and overriding them. Note that the merge is not deep merge (`Keyword.merge/2`). Defaults to `[]`.\n\n  * `:index` - path of the index file relative to the `:from` for the index. Defaults to `\"index.html\"`.\n\nAnd other options from `Plug.Static`:\n\n  * `:encodings`, `:gzip`, `:brotli`\n  * `:cache_control_for_etags`\n  * `:etag_generation`\n  * `:cache_control_for_vsn_requests`\n  * `:only`\n  * `:headers`\n  * `:content_types`\n\nPlease consult hexdocs for the details.","ref":"SpaPlug.html"},{"type":"extras","title":"SpaPlug","doc":"# SpaPlug\n\n[![Version](https://img.shields.io/hexpm/v/spa_plug.svg)](https://hex.pm/packages/spa_plug)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-purple.svg)](https://hexdocs.pm/spa_plug/)\n[![License](https://img.shields.io/badge/License-Apache%202.0-orange.svg)](https://opensource.org/license/apache-2-0/)\n\nA [plug](http://github.com/elixir-lang/plug) for serving single page apps directly from your Elixir application.","ref":"readme.html"},{"type":"extras","title":"Installation - SpaPlug","doc":"Add `spa_plug` to your dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    # ...\n    {:spa_plug, \"~> 1.0.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - SpaPlug","doc":"If using Phoenix, you can put it in `lib/your_app/endpoint.ex`. Order is important for plugs or middlewares in other frameworks. The same applies to `SpaPlug`, as it rewrites the `Plug.conn` as necessary. Also, keep in mind that potentially it can take over other routes. By default, `\"/api\"`, `\"/dev\"` and `\"/metrics\"` are already excluded, adjust `:except` for your specific needs or rearrange your plugs.\n\n```elixir\n  plug SpaPlug,\n    at: \"/\",\n    from: :your_app,\n    only: YourAppWeb.static_paths(),\n    # example: always up-to-date index page with immutable assets\n    # ref: https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Cache-Control#up-to-date_contents_always\n\n    # your assets should be requested with the query param \"vsn\", or include the headers below\n    # headers: [{\"cache-control\": \"max-age=31536000, immutable\"}],\n\n    # this assumes your index.html is in the default priv/static directory as well, otherwise pass :from in :index_merge_opts\n    index_merge_opts: [headers: [{\"cache-control\", \"no-cache\"}]]\n```","ref":"readme.html#usage"},{"type":"extras","title":"Documentation - SpaPlug","doc":"See https://hex.pm/packages/spa_plug.","ref":"readme.html#documentation"},{"type":"extras","title":"Compatibility - SpaPlug","doc":"The plug should be tested against the plug version listed in `mix.exs`.","ref":"readme.html#compatibility"},{"type":"extras","title":"Rationale - SpaPlug","doc":"Without the SSR on Node.js platform you will need to host your React or Vue.js apps as static assets. The typical solution would be to put a reverse proxy like Nginx in front. However, if you don't want to do it for some reason, there are no built-in or third party libraries for doing this. Plain `Plug.Static` would only serve the whole directory as it is.\n\nAlternatively you can also just use catch all requests and call `Plug.Conn.send_file/5` or `Phoenix.Controller.render/2` in your router or controller, but it is not as performant or flexible despite the inconvenience. With this plug your phoenix application can keep the same docker image from `mix phx.gen.release --docker`. It works standalone or with a CDN as well, just point it to your servers as origin.","ref":"readme.html#rationale"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v1.0.0 - Changelog","doc":"* Enhancements\n    * First public release","ref":"changelog.html#v1-0-0"}],"content_type":"text/markdown"}